Index: paste/script/command.py
===================================================================
--- paste/script/command.py	(revision 7040)
+++ paste/script/command.py	(working copy)
@@ -242,9 +242,10 @@
 
     def ask(self, prompt, safe=False, default=True):
         """
         Prompt the user.  Default can be true, false, ``'careful'`` or
         ``'none'``.  If ``'none'`` then the user must enter y/n.  If
         ``'careful'`` then the user must enter yes/no (long form).
 
         If the interactive option is over two (``-ii``) then ``safe``
         will be used as a default.  This option should be the
@@ -256,7 +257,7 @@
             default = safe
         if default == 'careful':
             prompt += ' [yes/no]?'
-        elif default == 'none':
+        elif default == 'none' or default == NoDefault:
             prompt += ' [y/n]?'
         elif default:
             prompt += ' [Y/n]? '
@@ -242,9 +242,10 @@
     def ask(self, prompt, safe=False, default=True):
         """
-        Prompt the user.  Default can be true, false, ``'careful'`` or
-        ``'none'``.  If ``'none'`` then the user must enter y/n.  If
-        ``'careful'`` then the user must enter yes/no (long form).
+        Prompt the user.  Default can be true, false, ``'careful'``,
+        ``'none'``, or the ``NoDefault`` class.  If ``'none'`` or
+        ``NoDefault`` then the user must enter y/n.  If ``'careful'``
+        then the user must enter yes/no (long form).
 
         If the interactive option is over two (``-ii``) then ``safe``

